==> SimplyDualWielding-4.3.1%2B1.21.%286%2B%29-Fabric-sources.jar: eva/dualwielding/DualWieldingMain.java <==
package eva.dualwielding;

import eva.dualwielding.access.ServerManagerAccess;
import eva.dualwielding.access.ServerPlayerAccess;
import eva.dualwielding.init.ParticleInit;
import eva.dualwielding.network.AttackPayload;
import eva.dualwielding.network.ConfigPayload;
import eva.dualwielding.network.ListPayload;
import eva.dualwielding.network.MinePayload;
import net.fabricmc.api.ModInitializer;
import net.fabricmc.fabric.api.networking.v1.PayloadTypeRegistry;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.minecraft.class_3222;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DualWieldingMain implements ModInitializer {

    public static final String MOD_ID = "sdw";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    @Override
    public void onInitialize() {
        ParticleInit.initServer();
        PayloadTypeRegistry.configurationS2C().register(ConfigPayload.ID, ConfigPayload.CODEC);
        PayloadTypeRegistry.configurationS2C().register(ListPayload.ID, ListPayload.CODEC);
        PayloadTypeRegistry.playC2S().register(AttackPayload.ID, AttackPayload.CODEC);
        ServerPlayNetworking.registerGlobalReceiver(AttackPayload.ID, (payload, context) -> {
            int entityId = payload.entityId();
            context.server().execute(() -> {
                class_3222 tp = context.player();
                tp.method_14234();
                if (context.player().method_51469().method_8469(entityId) != null) {
                    ((ServerPlayerAccess) tp).dualWielding$attackOffhand(tp.method_51469().method_8469(entityId));
                }
            });
        });

        PayloadTypeRegistry.playC2S().register(MinePayload.ID, MinePayload.CODEC);
        ServerPlayNetworking.registerGlobalReceiver(MinePayload.ID, (payload, context) -> {
            context.server().execute(() -> {
                class_3222 tp = context.player();
                ((ServerManagerAccess)tp.field_13974).dualWielding$processBlockBreakingAction(payload.method_12362(), payload.getReal(), payload.method_12360(), tp.method_51469().method_31600(), payload.method_42079());
                    tp.field_13987.method_41255(payload.method_42079());
            });
        });
    }
}

==> SimplyDualWielding-4.5.0%2B1.21.%286%2B%29-Fabric-sources.jar: eva/dualwielding/DualWieldingMain.java <==
package eva.dualwielding;

import eva.dualwielding.access.ServerManagerAccess;
import eva.dualwielding.access.ServerPlayerAccess;
import eva.dualwielding.init.ParticleInit;
import eva.dualwielding.network.AttackPayload;
import eva.dualwielding.network.ConfigPayload;
import eva.dualwielding.network.ListPayload;
import eva.dualwielding.network.MinePayload;
import net.fabricmc.api.ModInitializer;
import net.fabricmc.fabric.api.networking.v1.PayloadTypeRegistry;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_3222;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DualWieldingMain implements ModInitializer {

    public static final String MOD_ID = "sdw";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static boolean collectiveLoaded = false;

    @Override
    public void onInitialize() {
        ParticleInit.initServer();
        collectiveLoaded = FabricLoader.getInstance().isModLoaded("collective");
        PayloadTypeRegistry.configurationS2C().register(ConfigPayload.ID, ConfigPayload.CODEC);
        PayloadTypeRegistry.configurationS2C().register(ListPayload.ID, ListPayload.CODEC);
        PayloadTypeRegistry.playC2S().register(AttackPayload.ID, AttackPayload.CODEC);
        ServerPlayNetworking.registerGlobalReceiver(AttackPayload.ID, (payload, context) -> {
            int entityId = payload.entityId();
            context.server().execute(() -> {
                class_3222 tp = context.player();
                tp.method_14234();
                if (context.player().method_51469().method_8469(entityId) != null) {
                    ((ServerPlayerAccess) tp).dualWielding$attackOffhand(tp.method_51469().method_8469(entityId));
                }
            });
        });

        PayloadTypeRegistry.playC2S().register(MinePayload.ID, MinePayload.CODEC);
        ServerPlayNetworking.registerGlobalReceiver(MinePayload.ID, (payload, context) -> {
            context.server().execute(() -> {
                class_3222 tp = context.player();
                ((ServerManagerAccess)tp.field_13974).dualWielding$processBlockBreakingAction(payload.method_12362(), payload.getReal(), payload.method_12360(), tp.method_51469().method_31600(), payload.method_42079());
                    tp.field_13987.method_41255(payload.method_42079());
            });
        });
    }
}
